<?php declare(strict_types=1);

namespace FeedReaderCentral;

/**
 * An item from a feed
 */
class Item
{
    /**
     * Constructor
     *
     * @param int $id The ID of this item in the Feed Reader Central database
     * @param int $feed_id The ID of the feed to which this item belongs
     * @param string $title The title of this item
     * @param string $item_guid The Globally Unique ID (GUID) for this item (an attribute in the feed XML)
     * @param string $item_link The link to the item on its original site
     * @param string $published_on The date/time this item was published
     * @param string|null $updated_on The date/time this item was last updated
     * @param string $content The content for this item
     * @param int $is_read 1 if the item has been read, 0 if not
     * @param int $is_bookmarked 1 if the item is bookmarked, 0 if not
     */
    public function __construct(public int $id = 0, public int $feed_id = 0, public string $title = '',
                                public string $item_guid = '', public string $item_link = '',
                                public string $published_on = '', public ?string $updated_on = null,
                                public string $content = '', public int $is_read = 0, public int $is_bookmarked = 0) { }

    /**
     * Has the item been read?
     *
     * @return bool True if the item has been read, false if not
     */
    public function isRead(): bool
    {
        return $this->is_read <> 0;
    }

    /**
     * Is the item bookmarked?
     *
     * @return bool True if the item is bookmarked, false if not
     */
    public function isBookmarked(): bool
    {
        return $this->is_bookmarked <> 0;
    }

    /**
     * Create an item document from a parsed feed item
     *
     * @param int $feedId The ID of the feed to which this item belongs
     * @param ParsedItem $item The parsed feed item
     * @return static The item document
     */
    public static function fromFeedItem(int $feedId, ParsedItem $item): static
    {
        return new static(
            feed_id:      $feedId,
            title:        $item->title,
            item_guid:    $item->guid,
            item_link:    $item->link,
            published_on: $item->publishedOn,
            updated_on:   $item->updatedOn,
            content:      $item->content);
    }
}
